@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2018 Daniel Espinosa <esodan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,23 +29,7 @@
 G_BEGIN_DECLS
 
 #define GDAUI_TYPE_ENTRY_COMBO          (gdaui_entry_combo_get_type())
-#define GDAUI_ENTRY_COMBO(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gdaui_entry_combo_get_type(), GdauiEntryCombo)
-#define GDAUI_ENTRY_COMBO_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gdaui_entry_combo_get_type (), GdauiEntryComboClass)
-#define GDAUI_IS_ENTRY_COMBO(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gdaui_entry_combo_get_type ())
-
-
-typedef struct _GdauiEntryCombo      GdauiEntryCombo;
-typedef struct _GdauiEntryComboClass GdauiEntryComboClass;
-typedef struct _GdauiEntryComboPriv  GdauiEntryComboPriv;
-
-
-/* struct for the object's data */
-struct _GdauiEntryCombo
-{
-	GdauiEntryShell        object;
-	GdauiEntryComboPriv   *priv;
-};
-
+G_DECLARE_DERIVABLE_TYPE(GdauiEntryCombo, gdaui_entry_combo, GDAUI, ENTRY_COMBO, GdauiEntryShell)
 /* struct for the object's class */
 struct _GdauiEntryComboClass
 {
@@ -52,7 +37,6 @@ struct _GdauiEntryComboClass
 };
 
 
-GType           gdaui_entry_combo_get_type          (void) G_GNUC_CONST;
 GtkWidget      *gdaui_entry_combo_new               (GdauiSet *paramlist, GdauiSetSource *source);
 
 gboolean        gdaui_entry_combo_set_values        (GdauiEntryCombo *combo, GSList *values);
