@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2014 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,7 +28,7 @@ _gda_firebird_make_error (GdaConnection *cnc, const gint statement_type)
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
-	cdata = (FirebirdConnectionData*) gda_connection_internal_get_provider_data (cnc);
+	cdata = (FirebirdConnectionData*) gda_connection_internal_get_provider_data_error (cnc, NULL);
 	if (!cdata) 
 		return NULL;
 
