@@ -4,6 +4,7 @@
  * Copyright (C) 2001 Carlos Perelló Marín <carlos@gnome-db.org>
  * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
+ * Copyright (C) 2019 Daniel Espinosa <esodan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +25,7 @@
 #ifndef __GDA_PROXY_DATA_MODEL_LDAP_H__
 #define __GDA_PROXY_DATA_MODEL_LDAP_H__
 
-#include <libgda/gda-data-model-ldap.h>
+#include "gda-data-model-ldap.h"
 
 G_BEGIN_DECLS
 
@@ -34,6 +35,15 @@ GdaDataModel *_gdaprov_data_model_ldap_new       (GdaConnection *cnc,
 						  const gchar *attributes, GdaLdapSearchScope scope);
 GList        *gdaprov_data_model_ldap_compute_columns (GdaConnection *cnc, const gchar *attributes);
 
+
+#define GDAPROV_TYPE_DATA_MODEL_LDAP_ITER gdaprov_data_model_ldap_iter_get_type()
+
+G_DECLARE_DERIVABLE_TYPE(GdaprovDataModelLdapIter, gdaprov_data_model_ldap_iter, GDAPROV, DATA_MODEL_LDAP_ITER, GdaDataModelIter)
+
+struct _GdaprovDataModelLdapIterClass {
+	GdaDataModelIterClass parent_class;
+};
+
 G_END_DECLS
 
 #endif
