@@ -157,7 +157,7 @@ connection_binding_properties_new_create (TConnection *tcnc)
 	part = g_new0 (TVirtualConnectionPart, 1);
 	part->part_type = T_VIRTUAL_CONNECTION_PART_CNC;
 	part->u.cnc.table_schema = g_strdup (t_connection_get_name (tcnc));
-	part->u.cnc.source_cnc = g_object_ref (G_OBJECT (tcnc));
+	part->u.cnc.source_cnc = T_CONNECTION (g_object_ref (G_OBJECT (tcnc)));
 	specs->parts = g_slist_append (NULL, part);
 
 	cprop = CONNECTION_BINDING_PROPERTIES (g_object_new (CONNECTION_TYPE_BINDING_PROPERTIES, NULL));
@@ -213,22 +213,18 @@ static void
 create_layout (ConnectionBindingProperties *cprop)
 {
 	GtkWidget *label, *hbox;
-	gchar *str;
+	GString *str;
 	GtkWidget *dcontents;
 
 	dcontents = gtk_dialog_get_content_area (GTK_DIALOG (cprop));
 	gtk_container_set_border_width (GTK_CONTAINER (dcontents), 10);
 
-	str = g_strdup_printf ("<b>%s:</b>\n<small>%s</small>",
-			       _("Virtual connection's properties"),
-			       _("The virtual connection you are about to define can bind tables "
-				 "from an existing connection as well as bind a data set which will "
-				 "appear as a table (importing CSV data for example). "
-				 "You can add as many binds as needed"));
+	str = g_string_new (_("Virtual connection's properties."));
+	g_string_append (str, _("The virtual connection you are about to define can bind tables from an existing connection as well as bind a data set which will appear as a table (importing CSV data for example). You can add as many binds as needed"));
 
 	label = gtk_label_new ("");
-	gtk_label_set_markup (GTK_LABEL (label), str);
-	g_free (str);
+	gtk_label_set_markup (GTK_LABEL (label), str->str);
+	g_string_free (str, TRUE);
 	gtk_widget_set_halign (label, GTK_ALIGN_START);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_box_pack_start (GTK_BOX (dcontents), label, FALSE, FALSE, 0);
@@ -441,15 +437,12 @@ create_part_for_model (ConnectionBindingProperties *cprop, TVirtualConnectionPar
 	GdaSet *set;
 	GdaHolder *holder;
 	GtkWidget *form;
-	GValue *value;
 	set = gda_set_new_inline (1,
 				  "NAME", G_TYPE_STRING, pm->table_name);
 
-	holder = gda_holder_new (GDA_TYPE_DATA_MODEL);
-	g_object_set (holder, "id", "DATASET", "name", "Data set", NULL);
-	value = gda_value_new_from_string ("data-model-import", G_TYPE_STRING);
-	gda_holder_set_attribute_static (holder, GDAUI_ATTRIBUTE_PLUGIN, value);
-	gda_value_free (value);
+	holder = gda_holder_new (GDA_TYPE_DATA_MODEL, "DATASET");
+	g_object_set (holder, "name", "Data set", NULL);
+	g_object_set ((GObject*) holder, "plugin", "data-model-import", NULL);
 	g_assert (gda_set_add_holder (set, holder));
 	g_object_unref (holder);
 
@@ -555,20 +548,21 @@ create_part_for_cnc (ConnectionBindingProperties *cprop, TVirtualConnectionPart
 	set = gda_set_new_inline (1,
 				  "SCHEMA", G_TYPE_STRING, cnc->table_schema);
 
-	holder = gda_holder_new (T_TYPE_CONNECTION);
-	g_object_set (holder, "id", "CNC", "name", "Connection", "not-null", TRUE, NULL);
+	holder = gda_holder_new (T_TYPE_CONNECTION, "CNC");
+	g_object_set (holder, "name", _("Connection"), "not-null", TRUE,
+								"description", _("Connection to get tables from in the schema"), NULL);
 	g_assert (gda_set_add_holder (set, holder));
 
 	g_value_set_object ((value = gda_value_new (T_TYPE_CONNECTION)), cnc->source_cnc);
 	g_assert (gda_holder_set_value (holder, value, NULL));
 	gda_value_free (value);
 
-	g_assert (gda_holder_set_source_model (holder, t_app_get_all_connections_m (),
+  g_assert (gda_holder_set_source_model (holder, t_app_get_all_connections_m (),
 					       CNC_LIST_COLUMN_TCNC, NULL));
 	g_object_unref (holder);
 
 	holder = gda_set_get_holder (set, "SCHEMA");
-	g_object_set (holder, "name", "Schema",
+	g_object_set (holder, "name", _("Schema"),
 		      "description", _("Name of the schema the\ntables will be in"), NULL);
 							  
 	form = gdaui_basic_form_new (set);
