@@ -3,7 +3,7 @@
  * Copyright (C) 2001 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
  * Copyright (C) 2003 Danilo Schoeneberg <dj@starfire-programming.net>
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2015 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,12 +24,14 @@
 #include <gmodule.h>
 #include "perspective-main.h"
 #include "data-manager-perspective.h"
+#include "../perspectives-names.h"
 
 static BrowserPerspectiveFactory bfact;
 
 BrowserPerspectiveFactory *
 data_manager_perspective_get_factory (void)
 {
+	bfact.id = DATA_MANAGER_PERSPECTIVE_NAME;
 	bfact.perspective_name = _("Data manager");
 	bfact.menu_shortcut ="<control>D";
 	bfact.perspective_create = data_manager_perspective_new;
