@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2015 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
@@ -20,8 +20,9 @@
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
+#include "t-app.h"
 #include "relations-diagram.h"
-#include "../support.h"
+#include "../ui-customize.h"
 #include "../gdaui-bar.h"
 #include "../canvas/browser-canvas-db-relations.h"
 #include <gdk/gdkkeysyms.h>
@@ -30,10 +31,10 @@
 #include "../browser-perspective.h"
 #include "../browser-window.h"
 #include "../data-manager/data-manager-perspective.h"
-#include "../../tool-utils.h"
+#include "../ui-support.h"
 
 struct _RelationsDiagramPrivate {
-	BrowserConnection *bcnc;
+	TConnection *tcnc;
 	gint fav_id; /* diagram's ID as a favorite, -1=>not a favorite */
 
 	GdauiBar *header;
@@ -59,12 +60,12 @@ static void relations_diagram_get_property (GObject *object,
 
 /* BrowserPage interface */
 static void                 relations_diagram_page_init (BrowserPageIface *iface);
-static GtkActionGroup      *relations_diagram_page_get_actions_group (BrowserPage *page);
-static const gchar         *relations_diagram_page_get_actions_ui (BrowserPage *page);
-static GtkWidget           *relations_diagram_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button);
+static void                 relations_diagram_customize (BrowserPage *page, GtkToolbar *toolbar,
+							 GtkHeaderBar *header);
+static GtkWidget           *relations_diagram_get_tab_label (BrowserPage *page, GtkWidget **out_close_button);
 
-static void meta_changed_cb (BrowserConnection *bcnc, GdaMetaStruct *mstruct, RelationsDiagram *diagram);
-static void favorites_changed_cb (BrowserConnection *bcnc, RelationsDiagram *diagram);
+static void meta_changed_cb (TConnection *tcnc, GdaMetaStruct *mstruct, RelationsDiagram *diagram);
+static void favorites_changed_cb (TConnection *tcnc, RelationsDiagram *diagram);
 static void relations_diagram_set_fav_id (RelationsDiagram *diagram, gint fav_id, GError **error);
 
 /* properties */
@@ -96,9 +97,9 @@ relations_diagram_class_init (RelationsDiagramClass *klass)
 static void
 relations_diagram_page_init (BrowserPageIface *iface)
 {
-	iface->i_get_actions_group = relations_diagram_page_get_actions_group;
-	iface->i_get_actions_ui = relations_diagram_page_get_actions_ui;
-	iface->i_get_tab_label = relations_diagram_page_get_tab_label;
+	iface->i_customize = relations_diagram_customize;
+	iface->i_uncustomize = NULL;
+	iface->i_get_tab_label = relations_diagram_get_tab_label;
 }
 
 static void
@@ -118,12 +119,12 @@ relations_diagram_dispose (GObject *object)
 
 	/* free memory */
 	if (diagram->priv) {
-		if (diagram->priv->bcnc) {
-			g_signal_handlers_disconnect_by_func (diagram->priv->bcnc,
+		if (diagram->priv->tcnc) {
+			g_signal_handlers_disconnect_by_func (diagram->priv->tcnc,
 							      G_CALLBACK (meta_changed_cb), diagram);
-			g_signal_handlers_disconnect_by_func (diagram->priv->bcnc,
+			g_signal_handlers_disconnect_by_func (diagram->priv->tcnc,
 							      G_CALLBACK (favorites_changed_cb), diagram);
-			g_object_unref (diagram->priv->bcnc);
+			g_object_unref (diagram->priv->tcnc);
 		}
 
 		if (diagram->priv->popup_container)
@@ -197,13 +198,13 @@ relations_diagram_get_property (GObject *object,
 }
 
 static void
-meta_changed_cb (G_GNUC_UNUSED BrowserConnection *bcnc, GdaMetaStruct *mstruct, RelationsDiagram *diagram)
+meta_changed_cb (G_GNUC_UNUSED TConnection *tcnc, GdaMetaStruct *mstruct, RelationsDiagram *diagram)
 {
 	g_object_set (G_OBJECT (diagram->priv->canvas), "meta-struct", mstruct, NULL);
 }
 
 static void
-favorites_changed_cb (G_GNUC_UNUSED BrowserConnection *bcnc, RelationsDiagram *diagram)
+favorites_changed_cb (G_GNUC_UNUSED TConnection *tcnc, RelationsDiagram *diagram)
 {
 	if (diagram->priv->fav_id >= 0)
 		relations_diagram_set_fav_id (diagram, diagram->priv->fav_id, NULL);
@@ -220,12 +221,12 @@ real_save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 	str = browser_canvas_serialize_items (BROWSER_CANVAS (diagram->priv->canvas));
 
 	GError *lerror = NULL;
-	ToolsFavorites *bfav;
-	ToolsFavoritesAttributes fav;
+	TFavorites *bfav;
+	TFavoritesAttributes fav;
 
-	memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
+	memset (&fav, 0, sizeof (TFavoritesAttributes));
 	fav.id = diagram->priv->fav_id;
-	fav.type = GDA_TOOLS_FAVORITES_DIAGRAMS;
+	fav.type = T_FAVORITES_DIAGRAMS;
 	fav.name = gtk_editable_get_chars (GTK_EDITABLE (diagram->priv->name_entry), 0, -1);
 	if (!*fav.name) {
 		g_free (fav.name);
@@ -235,9 +236,9 @@ real_save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 	
 	gtk_widget_hide (diagram->priv->popup_container);
 	
-	bfav = browser_connection_get_favorites (diagram->priv->bcnc);
-	if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &lerror)) {
-		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel (button),
+	bfav = t_connection_get_favorites (diagram->priv->tcnc);
+	if (! t_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &lerror)) {
+		ui_show_error ((GtkWindow*) gtk_widget_get_toplevel (button),
 				    "<b>%s:</b>\n%s",
 				    _("Could not save diagram"),
 				    lerror && lerror->message ? lerror->message : _("No detail"));
@@ -274,11 +275,11 @@ save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
 		gtk_box_pack_start (GTK_BOX (hbox), wid, FALSE, FALSE, 5);
 		diagram->priv->name_entry = wid;
 		if (diagram->priv->fav_id > 0) {
-			ToolsFavoritesAttributes fav;
-			if (gda_tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+			TFavoritesAttributes fav;
+			if (t_favorites_get (t_connection_get_favorites (diagram->priv->tcnc),
 						   diagram->priv->fav_id, &fav, NULL)) {
 				gtk_entry_set_text (GTK_ENTRY (wid), fav.name);
-				gda_tools_favorites_reset_attributes (&fav);
+				t_favorites_reset_attributes (&fav);
 			}
 		}
 
@@ -304,18 +305,18 @@ save_clicked_cb (GtkWidget *button, RelationsDiagram *diagram)
  * Returns: a new #GtkWidget
  */
 GtkWidget *
-relations_diagram_new (BrowserConnection *bcnc)
+relations_diagram_new (TConnection *tcnc)
 {
 	RelationsDiagram *diagram;
 
-	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	g_return_val_if_fail (T_IS_CONNECTION (tcnc), NULL);
 
 	diagram = RELATIONS_DIAGRAM (g_object_new (RELATIONS_DIAGRAM_TYPE, NULL));
 
-	diagram->priv->bcnc = g_object_ref (bcnc);
-	g_signal_connect (diagram->priv->bcnc, "meta-changed",
+	diagram->priv->tcnc = g_object_ref (tcnc);
+	g_signal_connect (diagram->priv->tcnc, "meta-changed",
 			  G_CALLBACK (meta_changed_cb), diagram);
-	g_signal_connect (bcnc, "favorites-changed",
+	g_signal_connect (tcnc, "favorites-changed",
 			  G_CALLBACK (favorites_changed_cb), diagram);
 
 
@@ -332,7 +333,7 @@ relations_diagram_new (BrowserConnection *bcnc)
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	diagram->priv->header = GDAUI_BAR (label);
 
-	wid = gdaui_bar_add_button_from_stock (GDAUI_BAR (label), GTK_STOCK_SAVE);
+	wid = gdaui_bar_add_button_from_icon_name (GDAUI_BAR (label), "document-save");
 	diagram->priv->save_button = wid;
 
 	g_signal_connect (wid, "clicked",
@@ -347,34 +348,34 @@ relations_diagram_new (BrowserConnection *bcnc)
         gtk_widget_show_all (wid);
 	
 	GdaMetaStruct *mstruct;
-	mstruct = browser_connection_get_meta_struct (diagram->priv->bcnc);
+	mstruct = t_connection_get_meta_struct (diagram->priv->tcnc);
 	if (mstruct)
-		meta_changed_cb (diagram->priv->bcnc, mstruct, diagram);
+		meta_changed_cb (diagram->priv->tcnc, mstruct, diagram);
 	
 	return (GtkWidget*) diagram;
 }
 
 GtkWidget *
-relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError **error)
+relations_diagram_new_with_fav_id (TConnection *tcnc, gint fav_id, GError **error)
 {
 	RelationsDiagram *diagram = NULL;
-	ToolsFavoritesAttributes fav;
+	TFavoritesAttributes fav;
 	xmlDocPtr doc = NULL;
 
-	if (! gda_tools_favorites_get (browser_connection_get_favorites (bcnc),
+	if (! t_favorites_get (t_connection_get_favorites (tcnc),
 				     fav_id, &fav, error))
 		return FALSE;
 
 
 	doc = xmlParseDoc (BAD_CAST fav.contents);
 	if (!doc) {
-		g_set_error (error, GDA_TOOLS_ERROR, GDA_TOOLS_INTERNAL_COMMAND_ERROR,
+		g_set_error (error, T_ERROR, T_INTERNAL_COMMAND_ERROR,
 			     "%s", _("Error parsing favorite's contents"));
 		goto out;
 	}
 
 	/* create diagram */
-	diagram = RELATIONS_DIAGRAM (relations_diagram_new (bcnc));
+	diagram = RELATIONS_DIAGRAM (relations_diagram_new (tcnc));
 	if (!diagram)
 		goto out;
 	gchar *str, *tmp;
@@ -427,7 +428,7 @@ relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError
 					xmlFree (schema);
 				if (name)
 					xmlFree (name);
-				g_set_error (error, GDA_TOOLS_ERROR, GDA_TOOLS_STORED_DATA_ERROR,
+				g_set_error (error, T_ERROR, T_STORED_DATA_ERROR,
 					     "%s", _("Missing table attribute in favorite's contents"));
 				gtk_widget_destroy ((GtkWidget*) diagram);
 				diagram = NULL;
@@ -437,7 +438,7 @@ relations_diagram_new_with_fav_id (BrowserConnection *bcnc, gint fav_id, GError
 	}
 
  out:
-	gda_tools_favorites_reset_attributes (&fav);
+	t_favorites_reset_attributes (&fav);
 	if (doc)
 		xmlFreeDoc (doc);
 	return (GtkWidget*) diagram;
@@ -452,10 +453,10 @@ static void
 relations_diagram_set_fav_id (RelationsDiagram *diagram, gint fav_id, GError **error)
 {
 	g_return_if_fail (IS_RELATIONS_DIAGRAM (diagram));
-	ToolsFavoritesAttributes fav;
+	TFavoritesAttributes fav;
 
 	if ((fav_id >=0) &&
-	    gda_tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+	    t_favorites_get (t_connection_get_favorites (diagram->priv->tcnc),
 				   fav_id, &fav, error)) {
 		gchar *str, *tmp;
 		tmp = g_markup_printf_escaped (_("'%s' diagram"), fav.name);
@@ -466,7 +467,7 @@ relations_diagram_set_fav_id (RelationsDiagram *diagram, gint fav_id, GError **e
 		
 		diagram->priv->fav_id = fav.id;
 		
-		gda_tools_favorites_reset_attributes (&fav);
+		t_favorites_reset_attributes (&fav);
 	}
 	else {
 		gchar *str;
@@ -475,12 +476,6 @@ relations_diagram_set_fav_id (RelationsDiagram *diagram, gint fav_id, GError **e
 		g_free (str);
 		diagram->priv->fav_id = -1;
 	}
-
-	/* update notebook's tab label */
-	BrowserPerspective *pers;
-	pers = browser_page_get_perspective (BROWSER_PAGE (diagram));
-	if (pers)
-		browser_perspective_page_tab_label_change (pers, BROWSER_PAGE (diagram));
 }
 
 /**
@@ -495,8 +490,11 @@ relations_diagram_get_fav_id (RelationsDiagram *diagram)
 }
 
 static void
-action_view_contents_cb  (G_GNUC_UNUSED GtkAction *action, RelationsDiagram *diagram)
+action_view_contents_cb  (G_GNUC_UNUSED GSimpleAction *action, G_GNUC_UNUSED GVariant *state, gpointer data)
 {
+	RelationsDiagram *diagram;
+	diagram = RELATIONS_DIAGRAM (data);
+
 	gchar *str;
 	str = browser_canvas_db_relations_items_to_data_manager (BROWSER_CANVAS_DB_RELATIONS (diagram->priv->canvas));
 	g_print ("%s\n", str);
@@ -512,41 +510,33 @@ action_view_contents_cb  (G_GNUC_UNUSED GtkAction *action, RelationsDiagram *dia
 	}
 }
 
-
-static GtkActionEntry ui_actions[] = {
-	{ "ViewContents", GTK_STOCK_EDIT, N_("_Contents"), NULL, N_("View contents"),
-	  G_CALLBACK (action_view_contents_cb)},
+static GActionEntry win_entries[] = {
+	{ "ViewContents", action_view_contents_cb, NULL, NULL, NULL },
 };
-static const gchar *ui_actions_info =
-	"<ui>"
-	"  <menubar name='MenuBar'>"
-	"  </menubar>"
-	"  <toolbar name='ToolBar'>"
-	"    <separator/>"
-	"    <toolitem action='ViewContents'/>"
-	"  </toolbar>"
-	"</ui>";
 
-static GtkActionGroup *
-relations_diagram_page_get_actions_group (BrowserPage *page)
+static void
+relations_diagram_customize (BrowserPage *page, GtkToolbar *toolbar, GtkHeaderBar *header)
 {
-	GtkActionGroup *agroup;
-	agroup = gtk_action_group_new ("SchemaBrowserRelationsDiagramActions");
-	gtk_action_group_set_translation_domain (agroup, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (agroup, ui_actions, G_N_ELEMENTS (ui_actions), page);
-	
-	return agroup;
-}
+	g_print ("%s ()\n", __FUNCTION__);
 
-static const gchar *
-relations_diagram_page_get_actions_ui (G_GNUC_UNUSED BrowserPage *page)
-{
-	return ui_actions_info;
-}
+	customization_data_init (G_OBJECT (page), toolbar, header);
 
+	/* add perspective's actions */
+	customization_data_add_actions (G_OBJECT (page), win_entries, G_N_ELEMENTS (win_entries));
+
+	/* add to toolbar */
+	GtkToolItem *titem;
+	titem = gtk_tool_button_new (NULL, NULL);
+	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (titem), "go-jump-symbolic");
+	gtk_widget_set_tooltip_text (GTK_WIDGET (titem), _("Manage data in selected tables"));
+	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), titem, -1);
+	gtk_actionable_set_action_name (GTK_ACTIONABLE (titem), "win.ViewContents");
+	gtk_widget_show (GTK_WIDGET (titem));
+	customization_data_add_part (G_OBJECT (page), G_OBJECT (titem));
+}
 
 static GtkWidget *
-relations_diagram_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
+relations_diagram_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
 {
 	GtkWidget *wid;
 	RelationsDiagram *diagram;
@@ -555,20 +545,20 @@ relations_diagram_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_b
 
 	diagram = RELATIONS_DIAGRAM (page);
 	if (diagram->priv->fav_id > 0) {
-		ToolsFavoritesAttributes fav;
-		if (gda_tools_favorites_get (browser_connection_get_favorites (diagram->priv->bcnc),
+		TFavoritesAttributes fav;
+		if (t_favorites_get (t_connection_get_favorites (diagram->priv->tcnc),
 					   diagram->priv->fav_id, &fav, NULL)) {
 			tab_name = g_strdup (fav.name);
-			gda_tools_favorites_reset_attributes (&fav);
+			t_favorites_reset_attributes (&fav);
 		}
 	}
 	if (!tab_name)
 		tab_name = g_strdup (_("Diagram"));
 
-	table_pixbuf = browser_get_pixbuf_icon (BROWSER_ICON_DIAGRAM);
-	wid = browser_make_tab_label_with_pixbuf (tab_name,
-						  table_pixbuf,
-						  out_close_button ? TRUE : FALSE, out_close_button);
+	table_pixbuf = ui_get_pixbuf_icon (UI_ICON_DIAGRAM);
+	wid = ui_make_tab_label_with_pixbuf (tab_name,
+					     table_pixbuf,
+					     out_close_button ? TRUE : FALSE, out_close_button);
 	g_free (tab_name);
 	return wid;
 }
